Module recommend

Module recommend 

Parameter recommendation engine

Combines analysis results to generate optimal stt-build parameters.

Structs

Recommendations
Recommended parameters for stt-build.

Functions

generate_recommendations
Generate recommendations from analysis results, attaching the advisor suggestions (pass an empty Vec when the advisors were not run).
to_build_config
Convert recommendations to a build config JSON structure
to_command
Convert recommendations to an stt-build command line.